* =================================================================
CALCULATE COMBINED WEALTH SCORES, CHECK RESULTS
==================================================================


*	Urban and rural constants and coefficients regressed on the initial (common) wealth scores are used to produce combined wealth scores.
*	For the urban households, the combined wealth score will be calculated by
		urban constant + (urban coefficient * urban score)
	For the rural households, the combined wealth score will be calculated by
		rural constant + (rural coefficient * rural score).

use all.

*================================================================================================.
*	Calculate combined wealth scores.
compute comscore=0.
variable labels comscore "Combined wealth score".
formats comscore (f11.5).

if (urban = 1) comscore = urbconst + (urbcoeff * urbscore).
if (rural = 1)   comscore = rurconst + (rurcoeff * rurscore).
execute.

rename variables (ini1 = iniscore).

*================================================================================================.
* 	Weight the data by the product of the sample weight and the number of household members
	In essence, assign weights to households by taking their size (number of people) into consideration
	This will make possible to define quintiles of the "population", rather than households.
compute hhmemwt = hh11 * hhweight.
weight by hhmemwt.
variable labels hhmemwt 'Household members weight'.


*================================================================================================.
*	Distributions and histograms - total, urban and rural.
frequencies
  variables=iniscore comscore urbscore rurscore /format=notable
  /ntiles= 5
  /statistics=stddev mean
  /histogram  normal
  /order=analysis.

use all.
execute.

* 	Create the SPSS output.
output save outfile = "wealth7 syntax output run number X.spv".

* 	After reviewing the output close it.
output close.

